@@ -314,6 +314,6 @@ class DataMediator:
                 if dataGroup == "train"
                 else self.holdoutLabels,
                 "y_pred": np.argmax(probabilities, axis=1),
-                "y_probas": [probabilities],
+                "y_probas": probabilities,
             }
         )
